@@ -110,12 +110,13 @@ class Case(UUIDModel):
     STATUS_RUNNING = "running"
     STATUS_COMPLETED = "completed"
     STATUS_CANCELED = "canceled"
+    STATUS_SUSPENDED = "suspended"
 
-    STATUS_CHOICES = (STATUS_RUNNING, STATUS_COMPLETED, STATUS_CANCELED)
     STATUS_CHOICE_TUPLE = (
         (STATUS_RUNNING, "Case is running and work items need to be completed."),
         (STATUS_COMPLETED, "Case is done."),
-        (STATUS_CANCELED, "Case is cancelled."),
+        (STATUS_CANCELED, "Case is canceled."),
+        (STATUS_SUSPENDED, "Case is suspended."),
     )
 
     family = models.ForeignKey(
@@ -167,13 +168,14 @@ class WorkItem(UUIDModel):
     STATUS_COMPLETED = "completed"
     STATUS_CANCELED = "canceled"
     STATUS_SKIPPED = "skipped"
+    STATUS_SUSPENDED = "suspended"
 
-    STATUS_CHOICES = (STATUS_READY, STATUS_COMPLETED, STATUS_CANCELED)
     STATUS_CHOICE_TUPLE = (
-        (STATUS_READY, "Task is ready to be processed."),
-        (STATUS_COMPLETED, "Task is done."),
-        (STATUS_CANCELED, "Task is cancelled."),
-        (STATUS_SKIPPED, "Task is skipped."),
+        (STATUS_READY, "Work item is ready to be processed."),
+        (STATUS_COMPLETED, "Work item is done."),
+        (STATUS_CANCELED, "Work item is canceled."),
+        (STATUS_SKIPPED, "Work item is skipped."),
+        (STATUS_SUSPENDED, "Work item is suspended."),
     )
 
     name = LocalizedField(
